==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Widgets/PropertyEditor/ts/PropertyEditor_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>AddCustomPropertyDialog</name>
    <message>
        <location filename="../AddCustomPropertyDialog.ui" line="+14"/>
        <source>Add Custom Property</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Dodaj niestandardowy obiekt</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Name:</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Nazwa bloku:
Nazwa warstwy:</translatorcomment>
        <translation type="unfinished">Nazwa:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Value:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type:</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Typ linii:
&amp;Typ pola:</translatorcomment>
        <translation type="obsolete">Typ:</translation>
    </message>
</context>
<context>
    <name>PropertyEditor</name>
    <message>
        <location filename="../PropertyEditor.js" line="+1320"/>
        <source>*VARIES*</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">* Różni *</translation>
    </message>
    <message>
        <location line="-1132"/>
        <source>:</source>
        <translatorcomment>--ignored colon--
--file: qt_pl.ts--
Załadowany dokument:
Wersja: </translatorcomment>
        <translation type="unfinished">:</translation>
    </message>
    <message>
        <location line="+150"/>
        <source>No Selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">No Selection</translation>
    </message>
    <message>
        <source>Geometry</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Zmodyfikuj właściwości obiektu i geometrię
Edytuj geometrię obiektu</translatorcomment>
        <translation type="obsolete">Geometria</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Specific Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Dependent Entities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Custom</source>
        <translatorcomment>--exact match--
--file: qvfb_pl.ts--
Niestandardowe..
Niestandardowy
Własne filtry</translatorcomment>
        <translation type="unfinished">Niestandardowy</translation>
    </message>
    <message>
        <location line="+166"/>
        <source>Index</source>
        <translatorcomment>--exact match--
--file: linguist_pl.ts--
Indeks
Uaktualnianie indeksu wyszukiwawczego</translatorcomment>
        <translation type="unfinished">Indeks</translation>
    </message>
    <message>
        <location line="+59"/>
        <source>Remove this property from selected objects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+68"/>
        <source>All</source>
        <translatorcomment>--exact match--
--file: qvfb_pl.ts--
&amp;Sąsiadująco w poziomie
Sąsiadująco w poziomie
Czy chcesz zamknąć plik
%1?</translatorcomment>
        <translation type="unfinished">Wszystkie</translation>
    </message>
    <message>
        <location line="+641"/>
        <source>Widgets</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Custom Property</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Dodaj niestandardowy obiekt</translation>
    </message>
    <message>
        <location line="-619"/>
        <source>Add custom property to selected objects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Góra - lewo
Środek - lewo</translatorcomment>
        <translation type="obsolete">Lewo</translation>
    </message>
    <message>
        <source>Center</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wskaż środek
Łuk: środek, punkt, kąty</translatorcomment>
        <translation type="obsolete">Wyśrodkuj</translation>
    </message>
    <message>
        <source>Right</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Góra - prawo
Środek - prawo</translatorcomment>
        <translation type="obsolete">Prawo</translation>
    </message>
    <message>
        <source>Aligned</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wyrównany
&amp;Wyrównany</translatorcomment>
        <translation type="obsolete">Wyrównany</translation>
    </message>
    <message>
        <source>Middle</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
&amp;Punkt centralny
Środek
Przyciągaj do punktów pośrednich</translatorcomment>
        <translation type="obsolete">Środek</translation>
    </message>
    <message>
        <source>Fit</source>
        <translatorcomment>--google--
Rozmieść na stronie
Dopasuj szerokość
Dopasuj stronę</translatorcomment>
        <translation type="obsolete">Dopasować</translation>
    </message>
    <message>
        <source>Top</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Upuść aby zakończyć przesuwanie widoku
Góra - prawo</translatorcomment>
        <translation type="obsolete">Do góry</translation>
    </message>
    <message>
        <source>Base</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
Rysuj łuki styczne do  obiektu podstawowego
Zaznacz obiekt podstawowy</translatorcomment>
        <translation type="obsolete">Podstawa</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Dół - lewo
Dół - prawo</translatorcomment>
        <translation type="obsolete">W dół</translation>
    </message>
    <message>
        <location line="+136"/>
        <source>Auto</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
&amp;Automatycznie
Automatycznie
Przyciąganie automatyczne</translatorcomment>
        <translation type="unfinished">Automatycznie</translation>
    </message>
    <message>
        <location line="+123"/>
        <source>Use auto measurement</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Użyj automatycznego pomiaru</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Yes</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
Tak
&amp;Tak</translatorcomment>
        <translation type="unfinished">Tak</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
Nie można otworzyć pliku %1. Proszę sprawdzić prawa.
Nie można otworzyć pliku %1. Proszę sprawdzić prawa
Nie można zapisać pliku %1. Proszę sprawdzić prawa.</translatorcomment>
        <translation type="unfinished">Nie</translation>
    </message>
    <message>
        <location line="+320"/>
        <location line="+57"/>
        <location line="+11"/>
        <source>Property Editor</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
Edytor właściwości
Skonfiguruj edytor właściwości</translatorcomment>
        <translation type="unfinished">Edytor właściwości</translation>
    </message>
    <message>
        <location filename="../PropertyEditor.ui" line="+40"/>
        <source>Selection:</source>
        <translatorcomment>--ignored colon--
--file: qt_pl.ts--</translatorcomment>
        <translation type="unfinished">Wybrane strony:</translation>
    </message>
    <message>
        <source>General</source>
        <translatorcomment>--google--
Ogólne ustawienia aplikacji
[2000-206F] General Punctuation
General Punctuation</translatorcomment>
        <translation type="obsolete">Ogólny</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>General Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Selection to a New Layer</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Przenieś zaznaczenie do nowej warstwy</translation>
    </message>
    <message>
        <location line="+104"/>
        <source>Linetype Scale:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+49"/>
        <source>Protected:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-143"/>
        <source>Handle:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Uchwyt:</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Display Z coordinates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Display properties of current block and current layer</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Widgets/PropertyEditor/ts/PropertyEditor_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>AddCustomPropertyDialog</name>
    <message>
        <location filename="../AddCustomPropertyDialog.ui" line="+14"/>
        <source>Add Custom Property</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Dodawanie dostosowanej właściwości</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Name:</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Nazwa bloku:
Nazwa warstwy:</translatorcomment>
        <translation>Nazwa:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Value:</source>
        <translation>Wartość:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Typ linii:
&amp;Typ pola:</translatorcomment>
        <translation type="obsolete">Typ:</translation>
    </message>
</context>
<context>
    <name>PropertyEditor</name>
    <message>
        <location filename="../PropertyEditor.js" line="+1392"/>
        <source>*VARIES*</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>*RÓŻNE*</translation>
    </message>
    <message>
        <location line="-1199"/>
        <source>:</source>
        <translatorcomment>--ignored colon--
--file: qt_pl.ts--
Załadowany dokument:
Wersja: </translatorcomment>
        <translation>:</translation>
    </message>
    <message>
        <location line="+151"/>
        <source>No Selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Brak zaznaczenia</translation>
    </message>
    <message>
        <source>Geometry</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Zmodyfikuj właściwości obiektu i geometrię
Edytuj geometrię obiektu</translatorcomment>
        <translation type="obsolete">Geometria</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Specific Properties</source>
        <translation>Szczegółowe</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Dependent Entities</source>
        <translation>Zależne obiekty</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Custom</source>
        <translatorcomment>--exact match--
--file: qvfb_pl.ts--
Niestandardowe..
Niestandardowy
Własne filtry</translatorcomment>
        <translation>Dostosowany</translation>
    </message>
    <message>
        <location line="+166"/>
        <source>Index</source>
        <translatorcomment>--exact match--
--file: linguist_pl.ts--
Indeks
Uaktualnianie indeksu wyszukiwawczego</translatorcomment>
        <translation>Indeks</translation>
    </message>
    <message>
        <location line="+77"/>
        <source>Remove this property from selected objects</source>
        <translation>Usuń właściwość z zaznaczonych obiektów</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>All</source>
        <translatorcomment>--exact match--
--file: qvfb_pl.ts--
&amp;Sąsiadująco w poziomie
Sąsiadująco w poziomie
Czy chcesz zamknąć plik
%1?</translatorcomment>
        <translation>Wszystkie</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Show all properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+621"/>
        <source>Widgets</source>
        <translation>Widżety</translation>
    </message>
    <message>
        <source>Add Custom Property</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Dodaj niestandardowy obiekt</translation>
    </message>
    <message>
        <location line="-667"/>
        <source>Add custom property to selected objects</source>
        <translation>Dodaj dostosowaną właściwość do zaznaczonych obiektów</translation>
    </message>
    <message>
        <source>Left</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Góra - lewo
Środek - lewo</translatorcomment>
        <translation type="obsolete">Lewo</translation>
    </message>
    <message>
        <source>Center</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wskaż środek
Łuk: środek, punkt, kąty</translatorcomment>
        <translation type="obsolete">Wyśrodkuj</translation>
    </message>
    <message>
        <source>Right</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Góra - prawo
Środek - prawo</translatorcomment>
        <translation type="obsolete">Prawo</translation>
    </message>
    <message>
        <source>Aligned</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wyrównany
&amp;Wyrównany</translatorcomment>
        <translation type="obsolete">Wyrównany</translation>
    </message>
    <message>
        <source>Middle</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
&amp;Punkt centralny
Środek
Przyciągaj do punktów pośrednich</translatorcomment>
        <translation type="obsolete">Środek</translation>
    </message>
    <message>
        <source>Fit</source>
        <translatorcomment>--google--
Rozmieść na stronie
Dopasuj szerokość
Dopasuj stronę</translatorcomment>
        <translation type="obsolete">Dopasować</translation>
    </message>
    <message>
        <source>Top</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Upuść aby zakończyć przesuwanie widoku
Góra - prawo</translatorcomment>
        <translation type="obsolete">Do góry</translation>
    </message>
    <message>
        <source>Base</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
Rysuj łuki styczne do  obiektu podstawowego
Zaznacz obiekt podstawowy</translatorcomment>
        <translation type="obsolete">Podstawa</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Dół - lewo
Dół - prawo</translatorcomment>
        <translation type="obsolete">W dół</translation>
    </message>
    <message>
        <location line="+163"/>
        <source>Auto</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
&amp;Automatycznie
Automatycznie
Przyciąganie automatyczne</translatorcomment>
        <translation>Automatycznie</translation>
    </message>
    <message>
        <location line="+128"/>
        <source>Use auto measurement</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Użyj automatycznego pomiaru</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Yes</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
Tak
&amp;Tak</translatorcomment>
        <translation>Tak</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
Nie można otworzyć pliku %1. Proszę sprawdzić prawa.
Nie można otworzyć pliku %1. Proszę sprawdzić prawa
Nie można zapisać pliku %1. Proszę sprawdzić prawa.</translatorcomment>
        <translation>Nie</translation>
    </message>
    <message>
        <location line="+336"/>
        <location line="+57"/>
        <location line="+11"/>
        <source>Property Editor</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
Edytor właściwości
Skonfiguruj edytor właściwości</translatorcomment>
        <translation>Edytor właściwości</translation>
    </message>
    <message>
        <location filename="../PropertyEditor.ui" line="+40"/>
        <source>Selection:</source>
        <translatorcomment>--ignored colon--
--file: qt_pl.ts--</translatorcomment>
        <translation>Zaznaczenie:</translation>
    </message>
    <message>
        <source>General</source>
        <translatorcomment>--google--
Ogólne ustawienia aplikacji
[2000-206F] General Punctuation
General Punctuation</translatorcomment>
        <translation type="obsolete">Ogólny</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>General Properties</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Color:</source>
        <translation>Kolor:</translation>
    </message>
    <message>
        <source>Move Selection to a New Layer</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Przenieś zaznaczenie do nowej warstwy</translation>
    </message>
    <message>
        <location line="+104"/>
        <source>Linetype Scale:</source>
        <translation>Skala rodzaju linii:</translation>
    </message>
    <message>
        <location line="+49"/>
        <source>Protected:</source>
        <translation>Chroniony:</translation>
    </message>
    <message>
        <location line="-143"/>
        <source>Handle:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Uchwyt:</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Display Z coordinates</source>
        <translation>Wyświetlanie współrzędnych Z</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Display properties of current block and current layer</source>
        <translation>Wyświetlanie właściwości aktualnego bloku i warstwy</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Allow adding custom properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Always show all properties (this may slow down selection of entities)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
